@@ -18,10 +18,14 @@ exec('npm update electron-releases && npm run build && npm test', {silent:true},
 
   } else {
 
+    exec('git add package.json package-lock.json', {silent:true});
+    exec('git commit -m "bump electron-releases"', {silent:true});
+    exec('git push origin master', {silent:true});
+
     exec('git status --porcelain', {silent:true}, function(code, stdout, stderr) {
       const indexHasUpdated = !!stdout.length;
       if(indexHasUpdated) {
-        exec('git add versions.js full-versions.js chromium-versions.js full-chromium-versions.js package.json package-lock.json', {silent:true});
+        exec('git add versions.js full-versions.js chromium-versions.js full-chromium-versions.js', {silent:true});
         exec('git commit -m "generate new version"', {silent:true});
         exec('npm version patch', {silent:true});
         exec('git push origin master', {silent:true});
