@@ -850,7 +850,9 @@ module.exports = {
 		"9.3.3",
 		"9.3.4",
 		"9.3.5",
-		"9.4.0"
+		"9.4.0",
+		"9.4.1",
+		"9.4.2"
 	],
 	"84.0.4129.0": [
 		"10.0.0-beta.1",
@@ -994,7 +996,9 @@ module.exports = {
 		"10.1.5",
 		"10.1.6",
 		"10.1.7",
-		"10.2.0"
+		"10.2.0",
+		"10.3.0",
+		"10.3.1"
 	],
 	"86.0.4234.0": [
 		"11.0.0-beta.1",
@@ -1095,6 +1099,11 @@ module.exports = {
 		"11.1.0",
 		"11.1.1"
 	],
+	"87.0.4280.141": [
+		"11.2.0",
+		"11.2.1",
+		"11.2.2"
+	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
 		"12.0.0-beta.3",
@@ -1107,6 +1116,7 @@ module.exports = {
 		"12.0.0-beta.10",
 		"12.0.0-beta.11",
 		"12.0.0-beta.12",
+		"12.0.0-beta.14",
 		"13.0.0-nightly.20201119",
 		"13.0.0-nightly.20201123",
 		"13.0.0-nightly.20201124",
@@ -1124,6 +1134,12 @@ module.exports = {
 		"13.0.0-nightly.20201211",
 		"13.0.0-nightly.20201214"
 	],
+	"89.0.4348.1": [
+		"12.0.0-beta.16",
+		"12.0.0-beta.18",
+		"12.0.0-beta.19",
+		"12.0.0-beta.20"
+	],
 	"87.0.4268.0": [
 		"12.0.0-nightly.20201013",
 		"12.0.0-nightly.20201014",
@@ -1154,6 +1170,22 @@ module.exports = {
 	],
 	"89.0.4359.0": [
 		"13.0.0-nightly.20201223",
-		"13.0.0-nightly.20210104"
+		"13.0.0-nightly.20210104",
+		"13.0.0-nightly.20210108",
+		"13.0.0-nightly.20210111"
+	],
+	"89.0.4386.0": [
+		"13.0.0-nightly.20210113",
+		"13.0.0-nightly.20210114",
+		"13.0.0-nightly.20210118",
+		"13.0.0-nightly.20210122",
+		"13.0.0-nightly.20210125"
+	],
+	"89.0.4389.0": [
+		"13.0.0-nightly.20210127",
+		"13.0.0-nightly.20210128",
+		"13.0.0-nightly.20210129",
+		"13.0.0-nightly.20210201",
+		"13.0.0-nightly.20210202"
 	]
 };
\ No newline at end of file
