@@ -609,6 +609,7 @@ module.exports = {
 	"9.3.5": "83.0.4103.122",
 	"9.4.0": "83.0.4103.122",
 	"9.4.1": "83.0.4103.122",
+	"9.4.2": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -699,6 +700,8 @@ module.exports = {
 	"10.1.6": "85.0.4183.121",
 	"10.1.7": "85.0.4183.121",
 	"10.2.0": "85.0.4183.121",
+	"10.3.0": "85.0.4183.121",
+	"10.3.1": "85.0.4183.121",
 	"11.0.0-beta.1": "86.0.4234.0",
 	"11.0.0-beta.3": "86.0.4234.0",
 	"11.0.0-beta.4": "86.0.4234.0",
@@ -765,6 +768,8 @@ module.exports = {
 	"11.1.0": "87.0.4280.88",
 	"11.1.1": "87.0.4280.88",
 	"11.2.0": "87.0.4280.141",
+	"11.2.1": "87.0.4280.141",
+	"11.2.2": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -777,6 +782,10 @@ module.exports = {
 	"12.0.0-beta.11": "89.0.4328.0",
 	"12.0.0-beta.12": "89.0.4328.0",
 	"12.0.0-beta.14": "89.0.4328.0",
+	"12.0.0-beta.16": "89.0.4348.1",
+	"12.0.0-beta.18": "89.0.4348.1",
+	"12.0.0-beta.19": "89.0.4348.1",
+	"12.0.0-beta.20": "89.0.4348.1",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -823,5 +832,14 @@ module.exports = {
 	"13.0.0-nightly.20210104": "89.0.4359.0",
 	"13.0.0-nightly.20210108": "89.0.4359.0",
 	"13.0.0-nightly.20210111": "89.0.4359.0",
-	"13.0.0-nightly.20210113": "89.0.4386.0"
+	"13.0.0-nightly.20210113": "89.0.4386.0",
+	"13.0.0-nightly.20210114": "89.0.4386.0",
+	"13.0.0-nightly.20210118": "89.0.4386.0",
+	"13.0.0-nightly.20210122": "89.0.4386.0",
+	"13.0.0-nightly.20210125": "89.0.4386.0",
+	"13.0.0-nightly.20210127": "89.0.4389.0",
+	"13.0.0-nightly.20210128": "89.0.4389.0",
+	"13.0.0-nightly.20210129": "89.0.4389.0",
+	"13.0.0-nightly.20210201": "89.0.4389.0",
+	"13.0.0-nightly.20210202": "89.0.4389.0"
 };
\ No newline at end of file
